#!perl -T
use 5.006;
use strict;
use warnings FATAL => 'all';
use Test::More;

use Mojo::Util::Collection;
use Mojo::Util::Model::User;

my $collection = Mojo::Util::Collection->new(
    items => [
        {
            id         => 1,
            first_name => 'Joe',
            last_name  => 'Doe',
            age        => 19
        },
        {
            id         => 2,
            first_name => 'Jane',
            last_name  => 'Doe',
            age        => 21
        },
        {
            id         => 3,
            first_name => 'John',
            last_name  => 'Doe',
            age        => 22
        },
        {
            id         => 4,
            first_name => 'Jill',
            last_name  => 'Doe',
            age        => 23
        },
    ],
    model => Mojo::Util::Model::User->new
);

is($collection->count, 4);
is($collection->get(1)->id, 2);

my $filtered = $collection->exclude({ id => 2 });

is($collection->count, 4);
is($filtered->count, 3);
is($filtered->get(1)->id, 3);

$filtered = $filtered->exclude({
    age => 22,
});

is($collection->count, 4);
is($filtered->count, 2);
is($filtered->get(1)->id, 4);

done_testing();
